@@ -64,7 +64,7 @@ sub prepare_info {
     }
     $info->{$ex}{$video_id}{title}           ||= time();
     $info->{$ex}{$video_id}{duration}        ||= '-:--:--';
-    $info->{$ex}{$video_id}{upload_date}     ||= '0000-00-00';
+    $info->{$ex}{$video_id}{upload_date}     ||= exists $info->{$ex}{$video_id}{upload_date_rel} ? '---------' : '0000-00-00';
     $info->{$ex}{$video_id}{upload_datetime} ||= '0000-00-00T00:00:00';
     $info->{$ex}{$video_id}{playlist_id} //= '';
     $info->{$ex}{$video_id}{uploader_id} //= $info->{$ex}{$video_id}{uploader} // '';
