@@ -59,7 +59,7 @@ sub get_youtube_list_info {
                 my $next_res = $ua->get( $url );
                 my $h_ref = decode_json( $next_res->decoded_content );
                 last PAGE if $h_ref->{content_html} !~ /\S/;
-                $content = '<!DOCTYPE html><html>' . $h_ref->{content_html} . '</html>';
+                my $content = '<!DOCTYPE html><html>' . $h_ref->{content_html} . '</html>';
                 _parse_yt_list_html( $content, $uploader, $tmp );
                 if ( $opt->{small_list_size} ) {
                    $#$tmp = 49 if @$tmp > 50;
@@ -87,33 +87,44 @@ sub _parse_yt_list_html {
     $dom->find( 'li[class="channels-content-item yt-shelf-grid-item"]' )
         ->each(
             sub {
-                my $duration        = $_->at(  'span[class="video-time"] > span[title]' )->text;
-                my $title           = $_->at(  'h3[class="yt-lockup-title"] > a[class]' )->attr( 'title' );
-                my $video_id        = $_->at(  'h3[class="yt-lockup-title"] > a[class]' )->attr( 'href' );
-                my $view_count      = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[0]->text;
-                my $upload_date_rel = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[1]->text;
-                $video_id =~ s/^.+=(?=[^=]{11}\z)//;
-                $view_count =~ s/^([0-9.,]+).+\z/$1/;
-                $view_count =~ s/[,.]//g;
-                if ( $duration =~ /^(?:\d\d?:){0,2}\d\d?\z/ ) {
-                    my $seconds = 0;
-                    my @u = ( 1, 60, 3600 );
-                    my @parts = reverse split ':', $duration;
-                    for my $i ( 0 .. $#parts ) {
-                        $seconds += $parts[$i] * $u[$i];
-                    }
-                    $duration = $seconds if $seconds;
-                }
-                push @$tmp, {
-                    date_sort       => ++$date_sort,
-                    duration        => $duration,
-                    video_id        => $video_id,
-                    title           => $title,
-                    uploader        => $uploader,
-                    view_count      => $view_count,
-                    upload_date_rel => $upload_date_rel,
-                    webpage_url     => sprintf( 'https://www.youtube.com/watch?v=%s', $video_id ),
+                my $entry = {
+                    uploader  => $uploader,
+                    date_sort => ++$date_sort,
                 };
+                my $el_video_id = $_->at(  'h3[class="yt-lockup-title"] > a[class]' );
+                if ( $el_video_id ) {
+                    $entry->{video_id} = $el_video_id->attr( 'href' );
+                    $entry->{video_id} =~ s/^.+=(?=[^=]{11}\z)//;
+                }
+                my $el_title = $_->at(  'h3[class="yt-lockup-title"] > a[class]' );
+                if ( $el_title ) {
+                    $entry->{title} = $el_title->attr( 'title' );
+                }
+                my $el_duration = $_->at(  'span[class="video-time"] > span[title]' );
+                if ( $el_duration ) {
+                    my $duration = $el_duration->text;
+                    if ( $duration && $duration =~ /^(?:\d\d?:){0,2}\d\d?\z/ ) {
+                        my $seconds = 0;
+                        my @u = ( 1, 60, 3600 );
+                        my @parts = reverse split ':', $duration;
+                        for my $i ( 0 .. $#parts ) {
+                            $seconds += $parts[$i] * $u[$i];
+                        }
+                        $entry->{duration} = $seconds if $seconds;
+                    }
+                }
+                my $el_view_count = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[0];
+                if ( $el_view_count ) {
+                    $entry->{view_count} = $el_view_count->text;
+                    $entry->{view_count} =~ s/^([0-9.,]+).+\z/$1/;
+                    $entry->{view_count} =~ s/[,.]//g;
+                }
+                my $el_upload_date_rel = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[1];
+                if ( $el_upload_date_rel ) {
+                    $entry->{upload_date_rel} = $el_upload_date_rel->text;
+                }
+                $entry->{webpage_url} = sprintf( 'https://www.youtube.com/watch?v=%s', $entry->{video_id} ) if $entry->{video_id};
+                push @$tmp, $entry;
             }
         );
 }
@@ -141,17 +152,22 @@ sub get_vimeo_list_info {
             $dom->find( 'div[id="browse_content"] > ol > li[id][data-position]' )
                 ->each(
                     sub {
-                        my $video_id    = $_->attr( 'id' );
-                        my $title       = $_->at( 'a' )->attr( 'title' );
-                        my $datetime    = $_->at( 'time' )->attr( 'datetime' );
+                        my $video_id = $_->attr( 'id' );
                         $video_id =~ s/^clip_//;
-                        push @$tmp, {
-                            video_id    => $video_id,
-                            title       => $title,
-                            published   => $datetime,
-                            uploader    => $uploader,
-                            webpage_url => sprintf( 'https://vimeo.com/%s', $video_id ),
+                        my $entry = {
+                            video_id => $video_id,
+                            uploader => $uploader,
                         };
+                        $entry->{webpage_url} = sprintf( 'https://vimeo.com/%s', $video_id ) if $video_id;
+                        my $el_title = $_->at( 'a' );
+                        if ( $el_title ) {
+                            $entry->{title} = $el_title->attr( 'title' );
+                        }
+                        my $el_published = $_->at( 'time' );
+                        if ( $el_published ) {
+                            $entry->{published} = $el_published->attr( 'datetime' );
+                        }
+                        push @$tmp, $entry;
                     }
                 );
             $next = $dom->at( 'a[rel="next"]' ) ? 1 : 0;
