@@ -63,7 +63,6 @@ sub get_download_infos {
             MENU: while ( 1 ) {
                 print "\n";
                 $opt->{up}++;
-                @$print_array = check_mapping_stdout( $opt, @$print_array );
                 print for @$print_array;
                 $opt->{up} += @$print_array;
                 print "\n";
@@ -140,13 +139,13 @@ sub get_download_infos {
             if ( $opt->{extractor_dir} ) {
                 my $extractor_dir = sanitize_for_path( $opt, $ex );
                 $video_dir = catdir $video_dir, $extractor_dir;
-                make_path encode_fs( $video_dir );
+                make_path encode_fs( $opt, $video_dir );
             }
             if ( $opt->{uploader_dir} == 2 || $opt->{uploader_dir} == 1 && $info->{$ex}{$video_id}{from_list} ) {
                 if ( length $info->{$ex}{$video_id}{uploader} ) {
                     my $name_uploader = sanitize_for_path( $opt, $info->{$ex}{$video_id}{uploader} );
                     $video_dir = catdir $video_dir, $name_uploader;
-                    make_path encode_fs( $video_dir );
+                    make_path encode_fs( $opt, $video_dir );
                 }
             }
             $info->{$ex}{$video_id}{video_dir} = $video_dir;
@@ -159,10 +158,9 @@ sub get_download_infos {
             print "\n";
             for my $fmt ( @$fmt_list ) {
                 $info->{$ex}{$video_id}{video_url}{$fmt} = $info->{$ex}{$video_id}{fmt_to_info}{$fmt}{url};
-                my $title = $info->{$ex}{$video_id}{title};
+                my $title = $info->{$ex}{$video_id}{title_filename};
                 my $ext   = $info->{$ex}{$video_id}{fmt_to_info}{$fmt}{ext};
                 $info->{$ex}{$video_id}{file_name}{$fmt} = catfile( $video_dir, get_filename( $opt, $title, $ext, $fmt ) );
-
                 $info->{$ex}{$video_id}{count} = $count;
                 $opt->{nr_videos}++;
 
